@@ -377,7 +377,7 @@ xfce_shortcuts_editor_create_contents (XfceShortcutsEditor *editor)
           gtk_accel_map_lookup_entry (entry.accel_path, &key);
           shortcut_text = gtk_accelerator_get_label (key.accel_key, key.accel_mods);
           shortcut_button = gtk_button_new_with_label (key.accel_key > 0 ? shortcut_text : "...");
-          gtk_widget_set_tooltip_text (shortcut_button, _("The current shortcut. Press to edit..."));
+          gtk_widget_set_tooltip_text (shortcut_button, _("The current shortcut. Click to edit..."));
           g_free (shortcut_text);
           gtk_box_pack_start (GTK_BOX (box2), shortcut_button, TRUE, TRUE, 0);
           gtk_widget_show (shortcut_button);
